@@ -544,9 +544,11 @@ available in your region/language."""))
         # Override release notes
         dialog.set_release_notes("""
             <ul>
-                <li>Fixed app crash due to changes in AVIF image format support</li>
-                <li>[Servers] MangaFire (EN/ES/ES_LA/FR/JA/PT/pt_BR): Update</li>
-                <li>[L10n] Updated Portuguese and Russian translations</li>
+                <li>[Reader] Added ability to apply filters to pages (brightness, contrast, grayscale, sepia, saturation)</li>
+                <li>[Reader] RTL/LTR/Vertical pager: Added keyboard zoom</li>
+                <li>[Reader] Webtoon pager: Fixed weird jumps during backward scrolling</li>
+                <li>[Servers] MangaWorld (IT): Update</li>
+                <li>[L10n] Updated Arabic and French translations</li>
             </ul>
             <p>Happy reading.</p>
         """)
