@@ -9,6 +9,7 @@ from gi.repository import Gdk
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
+from gi.repository import Pango
 
 from komikku.card.categories_list import CategoriesList
 from komikku.card.chapters_list import ChaptersList
@@ -25,6 +26,7 @@ from komikku.utils import MISSING_IMG_RESOURCE_PATH
 class CardPage(Adw.NavigationPage):
     __gtype_name__ = 'CardPage'
 
+    toolbar_view = Gtk.Template.Child('toolbar_view')
     left_button = Gtk.Template.Child('left_button')
     filters_button = Gtk.Template.Child('filters_button')
     title_stack = Gtk.Template.Child('title_stack')
@@ -45,6 +47,7 @@ class CardPage(Adw.NavigationPage):
     chapters_selection_mode_clear_reset_button = Gtk.Template.Child('chapters_selection_mode_clear_reset_button')
     chapters_selection_mode_menubutton = Gtk.Template.Child('chapters_selection_mode_menubutton')
     info_scrolledwindow = Gtk.Template.Child('info_scrolledwindow')
+    backdrop_picture = Gtk.Template.Child('backdrop_picture')
     title_box = Gtk.Template.Child('title_box')
     cover_box = Gtk.Template.Child('cover_box')
     name_label = Gtk.Template.Child('name_label')
@@ -262,6 +265,9 @@ class CardPage(Adw.NavigationPage):
         self.filters_dialog.present(self.window)
 
     def on_gesture_drag_end(self, _controller, _offset_x, _offset_y):
+        self.stack.set_opacity(1)
+        self.stack.remove_css_class('grayscale')
+
         if not self.pool_to_update:
             return
 
@@ -289,12 +295,15 @@ class CardPage(Adw.NavigationPage):
         if scroll_value != 0 or offset_y < 0 or self.selection_mode or start_x < 32 or start_y > self.get_height() / 3:
             return
 
+        self.stack.set_opacity(0.5)
+        self.stack.add_css_class('grayscale')
+
         self.pool_to_update_offset = offset_y
 
         if not self.pool_to_update:
             self.pool_to_update = True
             # Adjust revealer position
-            self.pool_to_update_revealer.set_margin_top(self.get_child().get_top_bar_height())
+            self.pool_to_update_revealer.set_margin_top(self.toolbar_view.get_top_bar_height())
             self.pool_to_update_revealer.props.transition_type = Gtk.RevealerTransitionType.NONE
             self.pool_to_update_revealer.set_reveal_child(True)
         else:
@@ -326,22 +335,20 @@ class CardPage(Adw.NavigationPage):
         if (self.window.page == self.props.tag or self.window.previous_page == self.props.tag) and self.manga.id == manga.id:
             self.manga = manga
 
-    def on_manga_updated(self, _updater, manga, result):
+    def on_manga_updated(self, _updater, manga, chapters_changes, synced):
         if (self.window.page == self.props.tag or self.window.previous_page == self.props.tag) and self.manga.id == manga.id:
             self.manga = manga
 
-            if manga.server.sync:
-                self.window.add_notification(_('Read progress synchronization with server completed successfully'))
-
-            if result['nb_recent_chapters'] > 0 or result['nb_deleted_chapters'] > 0 or result['synced']:
-                if self.chapters_list.populate():
-                    self.toggle_resume(True)
-                else:
-                    self.toggle_resume(False)
-
             self.info_box.populate()
             self.toggle_filters_button()
 
+            if sum(chapters_changes.values()) > 0:
+                self.chapters_list.populate()
+                self.refresh(unread_chapters=True)
+
+            if synced:
+                self.window.add_notification(_('Read progress synchronization with server completed successfully'))
+
     def on_open_in_browser_menu_clicked(self, _action, _gparam):
         if uri := self.manga.server.get_manga_url(self.manga.slug, self.manga.url):
             Gtk.UriLauncher.new(uri=uri).launch()
@@ -399,29 +406,23 @@ class CardPage(Adw.NavigationPage):
     def populate(self):
         self.chapters_list.set_sort_order(invalidate=False)
 
-        if self.chapters_list.populate():
-            self.toggle_resume(True)
-        else:
-            self.toggle_resume(False)
-
+        self.chapters_list.populate()
         self.categories_list.populate()
 
     def refresh(self, unread_chapters=False, info=False, chapters=None):
         if unread_chapters:
             self.set_unread_chapters_badge()
+
         if info:
             self.info_box.refresh()
+
         if chapters is not None:
             self.chapters_list.refresh(chapters)
 
-    def reinstantiate_server(self):
-        """Used when servers modules origin change: server variable needs to be re-instantiated"""
-
-        if self.manga:
-            self.manga._server = None
-
     def remove_backdrop(self):
         self.remove_css_class('backdrop')
+        self.backdrop_picture.set_paintable(None)
+        self.backdrop_picture.set_opacity(1)
 
     def set_actions_enabled(self, enabled):
         self.delete_action.set_enabled(enabled)
@@ -429,12 +430,28 @@ class CardPage(Adw.NavigationPage):
         self.sort_order_action.set_enabled(enabled)
 
     def set_backdrop(self):
-        if not self.manga or Adw.StyleManager.get_default().get_high_contrast() or not Settings.get_default().card_backdrop:
+        self.remove_backdrop()
+
+        method = Settings.get_default().card_backdrop_method
+        if not self.manga or Adw.StyleManager.get_default().get_high_contrast() or not method:
             return
 
-        if backdrop_colors_css := self.manga.backdrop_colors_css:
-            self.css_provider.load_from_string(backdrop_colors_css)
-            self.add_css_class('backdrop')
+        if method == 'blurred-cover':
+            if path := self.manga.backdrop_image_fs_path:
+                self.backdrop_picture.set_filename(path)
+
+                if info := self.manga.backdrop_info:
+                    if Adw.StyleManager.get_default().get_dark():
+                        opacity = 1 - info['luminance'][0]
+                    else:
+                        opacity = info['luminance'][1]
+                    self.backdrop_picture.set_opacity(opacity)
+
+        elif method == 'linear-gradient':
+            if css := self.manga.backdrop_colors_css:
+                self.css_provider.load_from_string(css)
+
+        self.add_css_class('backdrop')
 
     def set_unread_chapters_badge(self):
         # Show unread chapters (with Adw.ViewStackPage badge) if any
@@ -596,27 +613,28 @@ class InfoBox:
 
             for genre in sorted(manga.genres):
                 label = Gtk.Label()
+                label.set_ellipsize(Pango.EllipsizeMode.END)
                 label.set_markup(html_escape(genre))
                 label.set_css_classes(['genre-label', 'caption'])
                 self.genres_wrapbox.append(label)
 
-            self.genres_wrapbox.get_parent().get_parent().set_visible(True)
+            self.genres_wrapbox.get_parent().set_visible(True)
         else:
-            self.genres_wrapbox.get_parent().get_parent().set_visible(False)
+            self.genres_wrapbox.get_parent().set_visible(False)
 
         if manga.scanlators:
             self.scanlators_label.set_markup(html_escape(', '.join(manga.scanlators)))
-            self.scanlators_label.get_parent().get_parent().set_visible(True)
+            self.scanlators_label.get_parent().set_visible(True)
         else:
-            self.scanlators_label.get_parent().get_parent().set_visible(False)
+            self.scanlators_label.get_parent().set_visible(False)
 
         self.chapters_label.set_markup(str(len(manga.chapters)))
 
         if manga.last_update:
             self.last_update_label.set_markup(manga.last_update.strftime(_('%m/%d/%Y')))
-            self.last_update_label.get_parent().get_parent().set_visible(True)
+            self.last_update_label.get_parent().set_visible(True)
         else:
-            self.last_update_label.get_parent().get_parent().set_visible(False)
+            self.last_update_label.get_parent().set_visible(False)
 
         self.set_disk_usage()
 
