@@ -8,6 +8,7 @@ import textwrap
 
 from komikku.servers import Server
 from komikku.servers import USER_AGENT
+from komikku.servers.utils import TextImage
 from komikku.utils import get_buffer_mime_type
 
 
@@ -105,24 +106,25 @@ class Existentialcomics(Server):
         """
         if page.get('slug'):
             r = self.session_get(self.image_url.format(page['slug']))
-            name = page['slug']
-        else:
-            r = self.session_get(
-                'https://fakeimg.pl/1500x2126/ffffff/000000/',
-                params=dict(
-                    text='\n'.join(textwrap.wrap(page['text'], 25)),
-                    font_size=64,
-                    font='museo'
-                )
-            )
-            name = '{0}-alt-text.png'.format(page['name'])
+            if r.status_code != 200:
+                return None
 
-        mime_type = get_buffer_mime_type(r.content)
-        if not mime_type.startswith('image'):
-            return None
+            mime_type = get_buffer_mime_type(r.content)
+            if not mime_type.startswith('image'):
+                return None
+
+            name = page['slug']
+            content = r.content
+        else:
+            text = '\n'.join(textwrap.wrap(page['text'], 25))
+            image = TextImage(text)
+
+            mime_type = image.mime_type
+            name = f'{page["name"]}-alt-text.{image.format}'
+            content = image.content
 
         return dict(
-            buffer=r.content,
+            buffer=content,
             mime_type=mime_type,
             name=name,
         )
