@@ -9,7 +9,10 @@ class Mangareadercc(Paprika):
     id = 'mangareadercc'
     name = 'MangaReader (cc)'
     lang = 'en'
+
+    has_cf = True
     is_nsfw = True
 
     base_url = 'https://mangareader.in'
     logo_url = base_url + '/frontend/imgs/favicon16.png'
+    bypass_cf_url = base_url + '/manga/selena'
