@@ -15,7 +15,7 @@
 # Asura Scans [TR]
 # Atikrost [TR] (disabled)
 # Best Manga [RU] (disabled)
-# Fr-Scan (Id frdashscan) [FR]
+# Fr-Scan (Id frdashscan) [FR] (disabled)
 # Hunlight Scans [EN] (disabled)
 # Leomanga [ES]
 # Leviatanscans [EN] (disabled)
@@ -23,10 +23,10 @@
 # Mangas Origines [FR] (disabled)
 # MangaWeebs [EN] (disabled)
 # Manhuaus [EN]
-# Manhwa Hentai [EN]
+# Manhwa Hentai [EN] (disabled)
 # Phoenix Fansub [ES] (disabled)
-# Poseidon Scans [FR]
-# Reaperscans [AR/FR/ID/TR]
+# Poseidon Scans [FR] (disabled)
+# Reaperscans [AR/FR/ID/TR] (disabled)
 # Submanga [ES] (disabled)
 # ToonGod [EN]
 # Toonily [EN]
@@ -79,6 +79,8 @@ class Madara(Server):
     chapters_slug_range = (-2, -1)
     chapters_order = 'desc'
 
+    images_src_attr = 'src'
+
     def __init__(self):
         self.api_url = self.base_url + '/wp-admin/admin-ajax.php'
         self.manga_url = self.base_url + '/' + self.series_name + '/{0}/'
@@ -180,13 +182,13 @@ class Madara(Server):
                 # Remove emoji
                 status = remove_emoji_from_string(status)
 
-                if status in ('Completed', 'Terminé', 'Completé', 'Completo', 'Finalizado', 'Concluído', 'Tamamlandı', 'مكتملة', 'Закончена'):
+                if status in ('Completed', 'Terminé', 'Completé', 'Completo', 'Finalizado', 'Terminado', 'Concluído', 'Tamamlandı', 'مكتملة', 'Закончена'):
                     data['status'] = 'complete'
-                elif status in ('OnGoing', 'En Cours', 'En cours', 'Updating', 'Devam Ediyor', 'Em Lançamento', 'Em andamento', 'En Emision', 'En emisión', 'En Emisión', 'مستمرة', 'Продолжается', 'Выпускается'):
+                elif status in ('OnGoing', 'En Cours', 'En cours', 'Updating', 'Devam Ediyor', 'Em Lançamento', 'Em andamento', 'En curso', 'En Emision', 'En emisión', 'En Emisión', 'مستمرة', 'Продолжается', 'Выпускается'):
                     data['status'] = 'ongoing'
-                elif status in ('Canceled', 'Cancelada'):
+                elif status in ('Canceled', 'Cancelada', 'Cancelado'):
                     data['status'] = 'suspended'
-                elif status in ('On Hold', 'En pause', 'En Hiatus'):
+                elif status in ('On Hold', 'En pause', 'En Hiatus', 'En espera'):
                     data['status'] = 'hiatus'
 
         if self.details_synopsis_selector:
@@ -291,11 +293,9 @@ class Madara(Server):
                 # In case server uses a second <img> encapsulated in a <noscript> element
                 continue
 
-            img_url = img_element.get('data-src')
+            img_url = img_element.get(self.images_src_attr)
             if img_url is None:
-                img_url = img_element.get('data-lazy-src')
-                if img_url is None:
-                    img_url = img_element.get('src')
+                continue
 
             data['pages'].append(dict(
                 slug=None,
