@@ -22,7 +22,7 @@ class Rawdevart(Server):
 
     base_url = 'https://rawdevart.art'
     logo_url = base_url + '/public/icons/rawdevart-60x60.png'
-    media_url = 'https://cghentai.com'  # server 2: https://s3-rawuwu.b-cdn.net
+    media_url = 'https://s3.rawuwu.com'
     manga_url = base_url + '/{0}'
     api_search_url = base_url + '/ajax/search-manga'
     latest_updates_url = base_url + '/latest'
@@ -94,7 +94,11 @@ class Rawdevart(Server):
         pages = []
         for index, canvas in enumerate(soup.find_all('canvas')):
             image = canvas.get('data-srcset')
-            pages.append(dict(image=image, index=index + 1))
+            pages.append(dict(
+                image=image,
+                server=r_decoded['chapter_detail']['server'],
+                index=index + 1,
+            ))
 
         return dict(pages=pages)
 
@@ -103,7 +107,7 @@ class Rawdevart(Server):
         Returns chapter page scan (image) content
         """
         r = self.session_get(
-            f'{self.media_url}/{page["image"]}',
+            f'{page.get("server") or self.media_url}/{page["image"]}',
             headers={
                 'Referer': f'{self.base_url}/',
             }
