@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 import logging
@@ -23,9 +23,11 @@ class Anilist(Tracker):
     name = 'AniList'
     client_id = '21273'
 
-    authorize_url = f'https://anilist.co/api/v2/oauth/authorize?client_id={client_id}&response_type=token'  # noqa: E231
+    base_url = 'https://anilist.co'
+    logo_url = base_url + '/img/icons/favicon-32x32.png'
+    authorize_url = f'{base_url}/api/v2/oauth/authorize?client_id={client_id}&response_type=token'
     api_url = 'https://graphql.anilist.co'
-    manga_url = 'https://anilist.co/manga/{0}'
+    manga_url = base_url + '/manga/{0}'
 
     RELEASE_STATUSES = {
         'CANCELLED': 'Cancelled',
@@ -322,7 +324,7 @@ class Anilist(Tracker):
 
         query = f"""
             mutation {{
-                SaveMediaListEntry(mediaId: {id}, score: {score}, status: {status}, progress: {int(data['chapters_progress'])}) {{
+                SaveMediaListEntry(mediaId: {id}, score: {score}, status: {status}, progress: {data['chapters_progress']}) {{
                     id
                     mediaId
                     score
