@@ -17,7 +17,6 @@ import traceback
 import gi
 from PIL import Image
 import magic
-import pillow_heif
 import requests
 from requests.adapters import HTTPAdapter
 from requests.adapters import TimeoutSauce
@@ -45,12 +44,9 @@ MISSING_IMG_RESOURCE_PATH = '/info/febvre/Komikku/images/missing_file.png'
 REQUESTS_TIMEOUT = 5
 
 logger = logging.getLogger('komikku')
-logging.getLogger("PIL.Image").propagate = False
-logging.getLogger("PIL.PngImagePlugin").propagate = False
-logging.getLogger("PIL.TiffImagePlugin").propagate = False
-
-pillow_heif.register_avif_opener()
-pillow_heif.register_heif_opener()
+logging.getLogger('PIL.Image').propagate = False
+logging.getLogger('PIL.PngImagePlugin').propagate = False
+logging.getLogger('PIL.TiffImagePlugin').propagate = False
 
 
 def check_cmdline_tool(cmd):
@@ -129,8 +125,9 @@ def folder_size(path):
         return 0
 
     res = subprocess.run(['du', '-sh', path], stdout=subprocess.PIPE, check=False)
+    size = res.stdout.split()[0].decode()
 
-    return res.stdout.split()[0].decode()
+    return f'{size[:-1]} {size[-1]}iB'
 
 
 def get_buffer_mime_type(buffer):
@@ -517,7 +514,7 @@ class AsyncWorker(GObject.Object):
           RESULT turns out to be invalid, return an error dictionary
           in the form
 
-          {"AsyncWorkerError": "Gio.Task.is_valid returned False."}
+          {'AsyncWorkerError': 'Gio.Task.is_valid returned False.'}
 
         """
         value = None
@@ -525,8 +522,8 @@ class AsyncWorker(GObject.Object):
         if Gio.Task.is_valid(result, self):
             value = result.propagate_value().value
         else:
-            error = "Gio.Task.is_valid returned False."
-            value = {"AsyncWorkerError": error}
+            error = 'Gio.Task.is_valid returned False.'
+            value = {'AsyncWorkerError': error}
 
         return value
 
@@ -538,7 +535,6 @@ class BaseServer:
     headers = None
     headers_images = None
     http_client = 'requests'  # HTTP client
-    ignore_ssl_errors = False
     status = 'enabled'
 
     __sessions = {}  # to cache all existing sessions
@@ -586,10 +582,10 @@ class BaseServer:
             headers['If-None-Match'] = etag
 
         if self.session:
-            r = self.session.get(url, headers=headers, verify=not self.ignore_ssl_errors)
+            r = self.session.get(url, headers=headers)
         else:
             # Session object has not yet been instantiated (servers with login or using webview to complete challenge)
-            r = requests.get(url, headers=headers, verify=not self.ignore_ssl_errors)
+            r = requests.get(url, headers=headers)
         if not r.ok:
             return None, None, get_response_elapsed(r)
 
@@ -642,7 +638,6 @@ class BaseServer:
         return True
 
     def session_get(self, *args, **kwargs):
-        kwargs['verify'] = not self.ignore_ssl_errors
         try:
             r = retry_session(session=self.session).get(*args, **kwargs)
         except Exception as error:
@@ -652,7 +647,6 @@ class BaseServer:
         return r
 
     def session_patch(self, *args, **kwargs):
-        kwargs['verify'] = not self.ignore_ssl_errors
         try:
             r = self.session.patch(*args, **kwargs)
         except Exception as error:
@@ -662,7 +656,6 @@ class BaseServer:
         return r
 
     def session_post(self, *args, **kwargs):
-        kwargs['verify'] = not self.ignore_ssl_errors
         try:
             r = self.session.post(*args, **kwargs)
         except Exception as error:
@@ -672,7 +665,6 @@ class BaseServer:
         return r
 
     def session_put(self, *args, **kwargs):
-        kwargs['verify'] = not self.ignore_ssl_errors
         try:
             r = self.session.put(*args, **kwargs)
         except Exception as error:
